@@ -18,7 +18,7 @@ class MangaTownCom(Provider, Std):
         idx = self.re.search('/manga/[^/]+(?:/v\d+)?/c([^/]+)', self.chapter)
         return idx.group(1).replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}/')
 
     def get_manga_name(self) -> str:
