@@ -10,7 +10,7 @@ class ReadComicOnlineTo(Provider, Std):
     def get_chapter_index(self, no_increment=False) -> str:
         return str(self.chapter_id)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content(r'{}/Comic/{}')
 
     def get_manga_name(self) -> str:
