@@ -13,7 +13,7 @@ class SenMangaCom(Provider, Std):
             fmt += '-{}'
         return fmt.format(*idx)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
